# pypck
Open source LCN-PCK library written in Python

### Overview

**pypck** is an open source library written in Python which allows the connection to the [LCN (local control network) system](https://www.lcn.eu). It uses the vendor protocol LCN-PCK.
To get started an unused license of the coupling software LCN-PCHK and a hardware coupler is necessary.
The library is a prerequisite for the [Home Assistant](https://www.home-assistant.io/) LCN component and is based entirely on Python's asyncio.

**pypck** is a derivative of the [LCN openHAB binding](https://github.com/openhab/openhab1-addons/wiki/lcn-binding) from Tobias Jüttner with several inprovements.
